Mail class abstract final

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

manager MailManager
no setter

Static Methods

bcc(Object recipients) PendingMail
cc(Object recipients) PendingMail
fake() MailFake
mailer([String? name]) Mailer
raw(String text, void build(Email email)) Future<void>
send(Mailable mailable) Future<void>
to(Object recipients) PendingMail